==> component_builder-2.2.2.tar.gz: component_builder/src/Plugin/ComponentBuilder/Download.php <==
<?php

namespace Drupal\component_builder\Plugin\ComponentBuilder;

use Drupal\component_builder\Annotation\ComponentBuilder;
use Drupal\component_builder\ComponentBuilderBase;

/**
 * Provides 'Download' component.
 *
 * @ComponentBuilder(
 *   id = "download",
 *   label = @Translation("Download"),
 *   group = @Translation("General components"),
 *   template = "download"
 * )
 */
class Download extends ComponentBuilderBase {

  /**
   * {@inheritdoc}
   */
  public function getTemplatePath() {
    return $this->getComponentPath() . '/templates';
  }

  /**
   * {@inheritdoc}
   */
  public function prepareVariables(array &$variables) {
    if (isset($variables['elements']['#component_item'])) {
      $variables['#attached']['drupalSettings']['components']['download']['icons'] = [
        'pdf' => $this->getComponentPath() . '/assets/images/pdf-icon.png',
        'docx' => $this->getComponentPath() . '/assets/images/docx-icon.png',
        'xlsx' => $this->getComponentPath() . '/assets/images/excel-icon.png',
        'file' => $this->getComponentPath() . '/assets/images/file-icon.png',
        'image' => $this->getComponentPath() . '/assets/images/image-icon.png',
        'music' => $this->getComponentPath() . '/assets/images/music-icon.png',
        'txt' => $this->getComponentPath() . '/assets/images/txt-icon.png',
      ];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getLibraries() {
    return [
      'css' => [
        'theme' => [
          'components/component_download/assets/style.css' => [],
        ],
      ],
      'js' => [
        'components/component_download/assets/style.js' => [],
      ],
      'dependencies' => [
        'core/drupal',
        'core/jquery',
        'core/jquery.once',
      ],
      "version" => "VERSION",
    ];
  }

}

==> component_builder-3.0.1.tar.gz: component_builder/src/Plugin/ComponentBuilder/Download.php <==
<?php

namespace Drupal\component_builder\Plugin\ComponentBuilder;

use Drupal\component_builder\ComponentBuilderBase;

/**
 * Provides 'Download' component.
 *
 * @ComponentBuilder(
 *   id = "download",
 *   label = @Translation("Download"),
 *   group = @Translation("Listing"),
 *   template = "download"
 * )
 */
class Download extends ComponentBuilderBase {

  /**
   * {@inheritdoc}
   */
  public function getTemplatePath() {
    return $this->getComponentPath() . '/templates';
  }

  /**
   * {@inheritdoc}
   */
  public function prepareVariables(array &$variables) {
    if (isset($variables['elements']['#component_item'])) {
      $variables['#attached']['drupalSettings']['components']['download']['icons'] = [
        'pdf' => $this->getComponentPath() . '/assets/images/pdf-icon.png',
        'docx' => $this->getComponentPath() . '/assets/images/docx-icon.png',
        'xlsx' => $this->getComponentPath() . '/assets/images/excel-icon.png',
        'file' => $this->getComponentPath() . '/assets/images/file-icon.png',
        'image' => $this->getComponentPath() . '/assets/images/image-icon.png',
        'music' => $this->getComponentPath() . '/assets/images/music-icon.png',
        'txt' => $this->getComponentPath() . '/assets/images/txt-icon.png',
      ];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getLibraries() {
    return [
      'css' => [
        'theme' => [
          'components/component_download/assets/style.css' => [],
        ],
      ],
      'js' => [
        'components/component_download/assets/style.js' => [],
      ],
      'dependencies' => [
        'core/drupal',
        'core/jquery',
        'core/jquery.once',
      ],
      "version" => "VERSION",
    ];
  }

}
